@@ -1,6 +1,7 @@
 import os
 # binary imports
 from os import SEEK_SET
+from typing import List
 # import this to show warnings
 import warnings
 
@@ -22,9 +23,11 @@ class APReader:
         filepath        The path to the .bin file.
         Channels        List with Channels (channels.py).
     """
+    Channels: List[Channel]
+
     def __init__(self, path):
         self.filepath = path
-        self.Channels = [Channel]
+        self.Channels = []
         self.read()
         self.connect()
 
